==> 140967-kimtoy-1.8.tar.bz2: kimtoy-1.8/theme.h <==
/*
 *  This file is part of KIMToy, an input method frontend for KDE
 *  Copyright (C) 2011-2012 Ni Hui <shuizhuyuanluo@126.com>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License or (at your option) version 3 or any later version
 *  accepted by the membership of KDE e.V. (or its successor approved
 *  by the membership of KDE e.V.), which shall act as a proxy
 *  defined in Section 14 of version 3 of the license.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef THEME_H
#define THEME_H

#include "ui_theme.h"

#include <QTimer>
#include <KIcon>

#include "themelistview.h"

class ThemeWidget : public QWidget, public Ui::Theme
{
    Q_OBJECT
public:
    explicit ThemeWidget() {
        setupUi(this);
        refreshButton->setIcon(KIcon("view-refresh"));
        installButton->setIcon(KIcon("utilities-file-archiver"));
        downloadButton->setIcon(KIcon("get-hot-new-stuff"));
        connect(refreshButton, SIGNAL(clicked()), kcfg_ThemeUri, SLOT(reload()));
        connect(installButton, SIGNAL(clicked()), this, SLOT(installTheme()));
        connect(downloadButton, SIGNAL(clicked()), this, SLOT(downloadTheme()));
        QTimer::singleShot(0, kcfg_ThemeUri, SLOT(reload()));
    }
private Q_SLOTS:
    void installTheme();
    void downloadTheme();
};

#endif // THEME_H

==> 140967-kimtoy-1.91.tar.bz2: kimtoy-1.91/theme.h <==
/*
 *  This file is part of KIMToy, an input method frontend for KDE
 *  Copyright (C) 2011-2016 Ni Hui <shuizhuyuanluo@126.com>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License or (at your option) version 3 or any later version
 *  accepted by the membership of KDE e.V. (or its successor approved
 *  by the membership of KDE e.V.), which shall act as a proxy
 *  defined in Section 14 of version 3 of the license.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef THEME_H
#define THEME_H

#include "ui_theme.h"

#include <QIcon>
#include <QTimer>

#include "themelistview.h"

class ThemeWidget : public QWidget, public Ui::Theme
{
    Q_OBJECT
public:
    explicit ThemeWidget() {
        setupUi(this);
        refreshButton->setIcon(QIcon::fromTheme("view-refresh"));
        installButton->setIcon(QIcon::fromTheme("utilities-file-archiver"));
        downloadButton->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
        connect(refreshButton, SIGNAL(clicked()), kcfg_ThemeUri, SLOT(reload()));
        connect(installButton, SIGNAL(clicked()), this, SLOT(installTheme()));
        connect(downloadButton, SIGNAL(clicked()), this, SLOT(downloadTheme()));
        QTimer::singleShot(0, kcfg_ThemeUri, SLOT(reload()));
    }
private Q_SLOTS:
    void installTheme();
    void downloadTheme();
};

#endif // THEME_H
